<?php

namespace Litecms\Register4\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Register4\Http\Requests\Register4Request;
use Litecms\Register4\Interfaces\Register4RepositoryInterface;
use Litecms\Register4\Models\Register4;

/**
 * Resource controller class for register4.
 */
class Register4ResourceController extends BaseController
{

    /**
     * Initialize register4 resource controller.
     *
     * @param type Register4RepositoryInterface $register4
     *
     * @return null
     */
    public function __construct(Register4RepositoryInterface $register4)
    {
        parent::__construct();
        $this->repository = $register4;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Register4\Repositories\Criteria\Register4ResourceCriteria::class);
    }

    /**
     * Display a list of register4.
     *
     * @return Response
     */
    public function index(Register4Request $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Register4\Repositories\Presenter\Register4Presenter::class)
                ->$function();
        }

        $register4s = $this->repository->paginate();

        return $this->response->title(trans('register4::register4.names'))
            ->view('register4::register4.index', true)
            ->data(compact('register4s'))
            ->output();
    }

    /**
     * Display register4.
     *
     * @param Request $request
     * @param Model   $register4
     *
     * @return Response
     */
    public function show(Register4Request $request, Register4 $register4)
    {

        if ($register4->exists) {
            $view = 'register4::register4.show';
        } else {
            $view = 'register4::register4.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('register4::register4.name'))
            ->data(compact('register4'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new register4.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(Register4Request $request)
    {

        $register4 = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('register4::register4.name')) 
            ->view('register4::register4.create', true) 
            ->data(compact('register4'))
            ->output();
    }

    /**
     * Create new register4.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(Register4Request $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $register4                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('register4::register4.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('register4/register4/' . $register4->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/register4/register4'))
                ->redirect();
        }

    }

    /**
     * Show register4 for editing.
     *
     * @param Request $request
     * @param Model   $register4
     *
     * @return Response
     */
    public function edit(Register4Request $request, Register4 $register4)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('register4::register4.name'))
            ->view('register4::register4.edit', true)
            ->data(compact('register4'))
            ->output();
    }

    /**
     * Update the register4.
     *
     * @param Request $request
     * @param Model   $register4
     *
     * @return Response
     */
    public function update(Register4Request $request, Register4 $register4)
    {
        try {
            $attributes = $request->all();

            $register4->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('register4::register4.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('register4/register4/' . $register4->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('register4/register4/' . $register4->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the register4.
     *
     * @param Model   $register4
     *
     * @return Response
     */
    public function destroy(Register4Request $request, Register4 $register4)
    {
        try {

            $register4->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('register4::register4.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('register4/register4/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('register4/register4/' . $register4->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple register4.
     *
     * @param Model   $register4
     *
     * @return Response
     */
    public function delete(Register4Request $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('register4::register4.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('register4/register4'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/register4/register4'))
                ->redirect();
        }

    }

    /**
     * Restore deleted register4s.
     *
     * @param Model   $register4
     *
     * @return Response
     */
    public function restore(Register4Request $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('register4::register4.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/register4/register4'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/register4/register4/'))
                ->redirect();
        }

    }

}
