<?php

namespace Litecms\Register4\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Register4\Models\Register4;

class Register4Policy
{

    /**
     * Determine if the given user can view the register4.
     *
     * @param UserPolicy $user
     * @param Register4 $register4
     *
     * @return bool
     */
    public function view(UserPolicy $user, Register4 $register4)
    {
        if ($user->canDo('register4.register4.view') && $user->isAdmin()) {
            return true;
        }

        return $register4->user_id == user_id() && $register4->user_type == user_type();
    }

    /**
     * Determine if the given user can create a register4.
     *
     * @param UserPolicy $user
     * @param Register4 $register4
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('register4.register4.create');
    }

    /**
     * Determine if the given user can update the given register4.
     *
     * @param UserPolicy $user
     * @param Register4 $register4
     *
     * @return bool
     */
    public function update(UserPolicy $user, Register4 $register4)
    {
        if ($user->canDo('register4.register4.edit') && $user->isAdmin()) {
            return true;
        }

        return $register4->user_id == user_id() && $register4->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given register4.
     *
     * @param UserPolicy $user
     * @param Register4 $register4
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Register4 $register4)
    {
        return $register4->user_id == user_id() && $register4->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given register4.
     *
     * @param UserPolicy $user
     * @param Register4 $register4
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Register4 $register4)
    {
        if ($user->canDo('register4.register4.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given register4.
     *
     * @param UserPolicy $user
     * @param Register4 $register4
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Register4 $register4)
    {
        if ($user->canDo('register4.register4.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
